(model-recipes-nemotron-3-super)=

# Nemotron 3 Super

The recipe for training Nemotron 3 Super with NeMo Gym and NeMo RL can be found in this [NeMo RL guide](https://github.com/NVIDIA-NeMo/RL/blob/super-v3/docs/guides/nemotron-3-super.md).

The steps for training Nemotron 3 Super are similar to that of {ref}`model-recipes-nemotron-3-nano`, and a dedicated tutorial will be posted in this document soon!
